feature_selection
=================

.. automodule:: tsfresh.feature_selection
    :members:
    :undoc-members:
    :show-inheritance:

relevance
---------

.. automodule:: tsfresh.feature_selection.relevance
    :members:
    :undoc-members: _calculate_relevance_table_for_implicit_target
    :show-inheritance:

selection
---------

.. automodule:: tsfresh.feature_selection.selection
    :members:
    :undoc-members:
    :show-inheritance:

significance_tests
------------------

.. automodule:: tsfresh.feature_selection.significance_tests
    :members:
    :undoc-members:
    :show-inheritance:
